package com.chinacreator.quartz.directed.file.job;

import com.alibaba.fastjson.JSON;
import com.chinacreator.quartz.directed.file.service.FileOrderService;
import com.chinacreator.quartz.directed.file.service.MoveOrderService;
import com.chinacreator.quartz.directed.util.DateUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 将集约平台生成的日文件解析入库，补全剥离模块的订购关系
 */
@Component
public class DirectedSyncJob {
    private final static Logger LOGGER = LoggerFactory.getLogger(DirectedSyncJob.class);
    @Autowired
    private FileOrderService fileOrderService;

    @Autowired
    private MoveOrderService moveOrderService;

    /**
     * 从集约平台的SFTP中下载定向的日文件
     */
    @Scheduled(cron="0 30 18 * * ?")
    public void downfile(){
        System.out.println("-----------下载文件-----------");
        Map<String,Object> outmap=new HashMap<>();
        outmap.put("filename","200_sync_order_cancel_"+ DateUtil.getLastDate(-1) + ".txt");
        fileOrderService.downFile(outmap);
        LOGGER.info(DateUtil.NowTimeSS()+"|down_file|"+ JSON.toJSONString(outmap));
    }

    /**
     * 将下载的日文件解析入库
     */
    @Scheduled(cron="0 35 18 * * ?")
    public void syncOrder(){
        System.out.println("-----------解析订购记录-----------");
        Map<String,Object> outmap=new HashMap<>();
        List<String> filelist=new ArrayList<>();
        fileOrderService.queryFile(outmap,filelist);
        LOGGER.info(DateUtil.NowTimeSS()+"|order_sync|"+JSON.toJSONString(filelist)+"|"+ JSON.toJSONString(outmap));
    }

    /**
     * 将失效的订购关系数据移动到历史表中
     */
    @Scheduled(cron="0 10 0 1 * ? ")
    public void moveOrderToHis() {
        System.out.println("-----------将订购关系迁移到历史表-----------");

        moveOrderService.moveOrderToHis();

        LOGGER.info(DateUtil.NowTimeSS()+"|move_order_to_his|");
    }
}
